package com.usky.dxtop.service.impl;


import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.usky.dxtop.common.core.page.CommonPage;
import com.usky.dxtop.common.exception.CustomException;
import com.usky.dxtop.common.utils.StringUtils;
import com.usky.dxtop.common.utils.file.ImageUtils;
import com.usky.dxtop.common.utils.sign.Base64;
import com.usky.dxtop.mapper.StaffMapper;
import com.usky.dxtop.model.MsgLog;
import com.usky.dxtop.model.Staff;
import com.usky.dxtop.service.MsgLogService;
import com.usky.dxtop.service.StaffService;
import com.usky.dxtop.service.config.rabbitmq.cartget.CartGetConsumeConfig;
import com.usky.dxtop.service.config.rabbitmq.face.FaceConsumeConfig;
import com.usky.dxtop.service.config.rabbitmq.profile.ProfileConsumeConfig;
import com.usky.dxtop.service.vo.StaffRequest;
import org.springframework.amqp.rabbit.connection.CorrelationData;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author yq
 * @since 2021-09-28
 */
@Service
public class StaffServiceImpl extends ServiceImpl<StaffMapper, Staff> implements StaffService {

    @Autowired
    @Qualifier(CartGetConsumeConfig.TEMPLATE)
    private RabbitTemplate rabbitTemplate;

    @Autowired
    private MsgLogService msgLogService;


    @Autowired
    @Qualifier(ProfileConsumeConfig.TEMPLATE)
    private RabbitTemplate profileRabbitTemplate;


    @Autowired
    @Qualifier(FaceConsumeConfig.TEMPLATE)
    private RabbitTemplate faceRabbitTemplate;


    @Override
    public CommonPage<Staff> page(StaffRequest staffRequest) {
        IPage<Staff> page = new Page<>(staffRequest.getCurrent(), staffRequest.getSize());
        page = baseMapper.page(page, staffRequest.getStartTime(),
                staffRequest.getEndTime(),
                staffRequest.getName(),
                staffRequest.getPhone(),
                staffRequest.getCard());
        return new CommonPage<>(page.getRecords(),page.getTotal(),page.getCurrent(),page.getSize());
    }

    @Override
    public String getBalance(String card) {
        MsgLog msgLog = new MsgLog();
        msgLog.setBusinessId(0L);
        msgLog.setExchange(CartGetConsumeConfig.NAME);
        msgLog.setRoutingKey(CartGetConsumeConfig.NAME);
        msgLog.setRemark("获取卡余额");
        msgLogService.save(msgLog);
        Map<String,Object> map = new HashMap<>();
        map.put("seq",msgLog.getId());
        map.put("card",card);
        msgLog.setMsg(JSON.toJSONString(map));
        msgLogService.updateById(msgLog);
        CorrelationData correlationData = new CorrelationData(msgLog.getId().toString());
        rabbitTemplate.convertAndSend(msgLog.getExchange(), msgLog.getRoutingKey(), map,correlationData);
        return msgLog.getId().toString();
    }

    @Override
    public Staff one(String id, String phone, String card) {
        if (StringUtils.isBlank(id) && StringUtils.isBlank(phone) && StringUtils.isBlank(card)){
            throw new CustomException("手机号，用户编号，卡号至少输入一个");
        }
        return baseMapper.one(id,phone,card);
    }


    /**
     * 人员消息
     * @param staff
     */
    @Override
    public void personSendMessage(Staff staff,Integer type){
        Map<String,Object> map = new HashMap<>();
        map.put("type",type);
        map.put("card_type",1);
        map.put("card",staff.getCardId());
        map.put("name",staff.getName());
        map.put("mob",staff.getId());
        map.put("groupid",staff.getDeptId());
        map.put("tel",staff.getContacts());
        map.put("level_name","员工卡");
        MsgLog msgLog = new MsgLog();
        msgLog.setBusinessId(staff.getSId());
        msgLog.setExchange(ProfileConsumeConfig.NAME);
        msgLog.setRoutingKey(ProfileConsumeConfig.NAME);
        msgLogService.save(msgLog);
        map.put("seq",msgLog.getId());
        msgLog.setMsg(JSON.toJSONString(map));
        msgLogService.updateById(msgLog);
        CorrelationData correlationData = new CorrelationData(msgLog.getId().toString());
        profileRabbitTemplate.convertAndSend(msgLog.getExchange(), msgLog.getRoutingKey(), map,correlationData);
    }


    /**
     * 人脸
     * @param staff
     */
    @Override
    public void faceSendMessage(Staff staff){
        String encode = Base64.encode(ImageUtils.getImage(staff.getFaceId()));
        Map<String,Object> map = new HashMap<>();
        map.put("mob",staff.getId());
        MsgLog msgLog = new MsgLog();
        msgLog.setBusinessId(staff.getSId());
        msgLog.setExchange(FaceConsumeConfig.NAME);
        msgLog.setRoutingKey(FaceConsumeConfig.NAME);
        msgLogService.save(msgLog);
        map.put("seq",msgLog.getId());
        map.put("img",staff.getFaceId());
        msgLog.setMsg(JSON.toJSONString(map));
        msgLogService.updateById(msgLog);
        map.put("img",encode);
        CorrelationData correlationData = new CorrelationData(msgLog.getId().toString());
        faceRabbitTemplate.convertAndSend(msgLog.getExchange(), msgLog.getRoutingKey(), map,correlationData);
    }
}
